@@ -1,5 +1,5 @@
 # This is channelpack, load and filter data.
-# Copyright (C) 2014-2017, 2020 Tomas Nordin
+# Copyright (C) 2014-2017, 2020-2021 Tomas Nordin
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,9 +19,9 @@ Provide access to the ChannelPack class and som factory functions to get
 a pack.
 """
 
-from .pack import ChannelPack
-from .readtext import textpack, lazy_textpack
-from .dbf import dbfpack
-from .readxl import sheetpack
+from channelpack.pack import ChannelPack
+from channelpack.readtext import textpack, lazy_textpack
+from channelpack.dbf import dbfpack
+from channelpack.readxl import sheetpack
 
-__version__ = '0.6.2'
+__version__ = '0.7.0'
